@@ -12,7 +12,7 @@
 #include <inttypes.h>
 #include <avr/interrupt.h>
 #define F_CPU 4000000UL  // 4 MHz
-#include <avr/delay.h>
+#include <util/delay.h>
 #include "lcd.h"
 #include "dac.h"
 #include "kbd.h"
