@@ -15,7 +15,7 @@ Copyright: GPL
 #include <avr/io.h>
 #include <avr/pgmspace.h>
 #define F_CPU 4000000UL  // 4 MHz
-#include <avr/delay.h>
+#include <util/delay.h>
 
 #include "lcd_hw.h"
 #include "lcd.h"
@@ -71,7 +71,7 @@ void lcd_delay_ms(unsigned int ms)
         // accurate and not so much compiler dependent
         // as self made code.
         while(ms){
-                _delay_loop_2(240.0);
+                _delay_ms(0.96);
                 ms--;
         }
 }
@@ -142,10 +142,10 @@ static unsigned char lcd_waitcmd(unsigned char cmdwait)
  * has been changed to just delay a bit. In that case the LCD
  * is only slightly slower but we do not need the RW pin. */
 {
-        _delay_us(9);
+        _delay_us(8);
 	/* the display needs much longer to process a command */
 	if (cmdwait){
-		lcd_delay_ms(6);
+		lcd_delay_ms(2);
 	}
 	return (0); 
 }
@@ -219,7 +219,7 @@ void lcd_puts(const char *s)
 }
 
 
-void lcd_puts_p(const prog_char *progmem_s)
+void lcd_puts_p(const char *progmem_s)
 /* print string from program memory on lcd  */
 {
 	register char c;
@@ -242,20 +242,20 @@ void lcd_init(u08 dispAttr)
 	sbi(LCD_E_DDR, LCD_E_PIN);	/* E  pin as output */
 
 
-	lcd_delay_ms(16);	/* wait 16ms or more after power-on       */
+	lcd_delay_ms(12);	/* wait 12ms or more after power-on       */
 
 	/* initial write to lcd is 8bit */
 	lcd_out_high(LCD_FUNCTION_8BIT_1LINE);
 	lcd_e_toggle();
-	lcd_delay_ms(5);	/* delay, busy flag can't be checked here */
+	lcd_delay_ms(2);	/* delay, busy flag can't be checked here */
 
 	lcd_out_high(LCD_FUNCTION_8BIT_1LINE);
 	lcd_e_toggle();
-	lcd_waitcmd(1);		/* delay, busy flag can't be checked here */
+	lcd_delay_ms(2);	/* delay, busy flag can't be checked here */
 
 	lcd_out_high(LCD_FUNCTION_8BIT_1LINE);
 	lcd_e_toggle();
-	lcd_waitcmd(1);		/* delay, busy flag can't be checked here */
+	lcd_delay_ms(2);	/* delay, busy flag can't be checked here */
 
 	lcd_out_high(LCD_FUNCTION_4BIT_1LINE);	/* set IO mode to 4bit */
 	lcd_e_toggle();
