@@ -91,7 +91,7 @@ extern void lcd_puts(const char *s); /* print string on lcd (no auto linefeed) *
 /* if you hard code a string in the program then you need to decalare
 * it like: char *str =PSTR("hello world");
 * and then use lcd_puts_p(str);*/
-extern void lcd_puts_p(const prog_char *progmem_s); /* print string from program memory on lcd (no auto linefeed) */
+extern void lcd_puts_p(const char *progmem_s); /* print string from program memory on lcd (no auto linefeed) */
 extern void lcd_init(u08 dispAttr); /* initialize the LCD. Call this once*/
 
 /*
